@@ -226,7 +226,7 @@ MHD_lookup_connection_value (struct MHD_Connection *connection,
 	( (key == pos->header) ||
 	  ( (NULL != pos->header) &&
 	    (NULL != key) &&
-	    (0 == strcasecmp (key, pos->header))) ))
+        (MHD_str_equal_caseless_(key, pos->header)))))
       return pos->value;
   return NULL;
 }
@@ -246,12 +246,12 @@ need_100_continue (struct MHD_Connection *connection)
 
   return ( (NULL == connection->response) &&
 	   (NULL != connection->version) &&
-	   (0 == strcasecmp (connection->version,
+       (MHD_str_equal_caseless_(connection->version,
 			     MHD_HTTP_VERSION_1_1)) &&
 	   (NULL != (expect = MHD_lookup_connection_value (connection,
 							   MHD_HEADER_KIND,
 							   MHD_HTTP_HEADER_EXPECT))) &&
-	   (0 == strcasecmp (expect, "100-continue")) &&
+	   (MHD_str_equal_caseless_(expect, "100-continue")) &&
 	   (connection->continue_message_write_offset <
 	    strlen (HTTP_100_CONTINUE)) );
 }
@@ -476,7 +476,7 @@ try_ready_chunked_body (struct MHD_Connection *connection)
     }
   if (ret > 0xFFFFFF)
     ret = 0xFFFFFF;
-  snprintf (cbuf,
+  MHD_snprintf_ (cbuf,
 	    sizeof (cbuf),
 	    "%X\r\n", (unsigned int) ret);
   cblen = strlen (cbuf);
@@ -519,21 +519,22 @@ keepalive_possible (struct MHD_Connection *connection)
   end = MHD_lookup_connection_value (connection,
                                      MHD_HEADER_KIND,
                                      MHD_HTTP_HEADER_CONNECTION);
-  if (0 == strcasecmp (connection->version,
+  if (MHD_str_equal_caseless_(connection->version,
                        MHD_HTTP_VERSION_1_1))
   {
     if (NULL == end)
       return MHD_YES;
-    if (0 == strcasecmp (end, "close"))
+    if ( (MHD_str_equal_caseless_ (end, "close")) ||
+         (MHD_str_equal_caseless_ (end, "upgrade")) )
       return MHD_NO;
-    return MHD_YES;
+   return MHD_YES;
   }
-  if (0 == strcasecmp (connection->version,
+  if (MHD_str_equal_caseless_(connection->version,
                        MHD_HTTP_VERSION_1_0))
   {
     if (NULL == end)
       return MHD_NO;
-    if (0 == strcasecmp (end, "Keep-Alive"))
+    if (MHD_str_equal_caseless_(end, "Keep-Alive"))
       return MHD_YES;
     return MHD_NO;
   }
@@ -677,7 +678,7 @@ build_header_response (struct MHD_Connection *connection)
                "%s %u %s\r\n",
 	       (0 != (connection->responseCode & MHD_ICY_FLAG))
 	       ? "ICY"
-	       : ( (0 == strcasecmp (MHD_HTTP_VERSION_1_0,
+	       : ( (MHD_str_equal_caseless_ (MHD_HTTP_VERSION_1_0,
 				     connection->version))
 		   ? MHD_HTTP_VERSION_1_0
 		   : MHD_HTTP_VERSION_1_1),
@@ -685,7 +686,7 @@ build_header_response (struct MHD_Connection *connection)
 	       reason_phrase);
       off = strlen (code);
       /* estimate size */
-      size = off + 2;           /* extra \r\n at the end */
+      size = off + 2;           /* +2 for extra "\r\n" at the end */
       kind = MHD_HEADER_KIND;
       if ( (0 == (connection->daemon->options & MHD_SUPPRESS_DATE_NO_CLOCK)) &&
 	   (NULL == MHD_get_response_header (connection->response,
@@ -716,16 +717,16 @@ build_header_response (struct MHD_Connection *connection)
                                                     MHD_HTTP_HEADER_CONNECTION);
       response_has_keepalive = response_has_close;
       if ( (NULL != response_has_close) &&
-           (0 != strcasecmp (response_has_close, "close")) )
+           (!MHD_str_equal_caseless_ (response_has_close, "close")) )
         response_has_close = NULL;
       if ( (NULL != response_has_keepalive) &&
-           (0 != strcasecmp (response_has_keepalive, "Keep-Alive")) )
+           (!MHD_str_equal_caseless_ (response_has_keepalive, "Keep-Alive")) )
         response_has_keepalive = NULL;
       client_requested_close = MHD_lookup_connection_value (connection,
                                                             MHD_HEADER_KIND,
                                                             MHD_HTTP_HEADER_CONNECTION);
       if ( (NULL != client_requested_close) &&
-           (0 != strcasecmp (client_requested_close, "close")) )
+           (!MHD_str_equal_caseless_ (client_requested_close, "close")) )
         client_requested_close = NULL;
 
       /* now analyze chunked encoding situation */
@@ -749,7 +750,7 @@ build_header_response (struct MHD_Connection *connection)
                   must_add_chunked_encoding = MHD_YES;
                   connection->have_chunked_upload = MHD_YES;
                 }
-              else if (0 == strcasecmp (have_encoding, "identity"))
+              else if (MHD_str_equal_caseless_(have_encoding, "identity"))
                 {
                   /* application forced identity encoding, can't do 'chunked' */
                   must_add_close = MHD_YES;
@@ -781,7 +782,7 @@ build_header_response (struct MHD_Connection *connection)
       if ( (MHD_SIZE_UNKNOWN != connection->response->total_size) &&
            (NULL == have_content_length) &&
            ( (NULL == connection->method) ||
-             (0 != strcasecmp (connection->method,
+             (!MHD_str_equal_caseless_ (connection->method,
                                MHD_HTTP_METHOD_CONNECT)) ) )
         {
           /*
@@ -833,9 +834,9 @@ build_header_response (struct MHD_Connection *connection)
 
   for (pos = connection->response->first_header; NULL != pos; pos = pos->next)
     if ( (pos->kind == kind) &&
-         (! ( (pos->value == response_has_keepalive) &&
-              (MHD_YES == must_add_close) &&
-              (0 == strcasecmp (pos->header,
+         (! ( (MHD_YES == must_add_close) &&
+              (pos->value == response_has_keepalive) &&
+              (MHD_str_equal_caseless_(pos->header,
                                 MHD_HTTP_HEADER_CONNECTION) ) ) ) )
       size += strlen (pos->header) + strlen (pos->value) + 4; /* colon, space, linefeeds */
   /* produce data */
@@ -888,7 +889,7 @@ build_header_response (struct MHD_Connection *connection)
     if ( (pos->kind == kind) &&
          (! ( (pos->value == response_has_keepalive) &&
               (MHD_YES == must_add_close) &&
-              (0 == strcasecmp (pos->header,
+              (MHD_str_equal_caseless_(pos->header,
                                 MHD_HTTP_HEADER_CONNECTION) ) ) ) )
       off += sprintf (&data[off],
 		      "%s: %s\r\n",
@@ -1306,7 +1307,8 @@ parse_cookie_header (struct MHD_Connection *connection)
   if (NULL == cpy)
     {
 #if HAVE_MESSAGES
-      MHD_DLOG (connection->daemon, "Not enough memory to parse cookies!\n");
+      MHD_DLOG (connection->daemon,
+                "Not enough memory to parse cookies!\n");
 #endif
       transmit_error_response (connection, MHD_HTTP_REQUEST_ENTITY_TOO_LARGE,
                                REQUEST_TOO_BIG);
@@ -1914,7 +1916,7 @@ parse_connection_headers (struct MHD_Connection *connection)
   parse_cookie_header (connection);
   if ( (0 != (MHD_USE_PEDANTIC_CHECKS & connection->daemon->options)) &&
        (NULL != connection->version) &&
-       (0 == strcasecmp (MHD_HTTP_VERSION_1_1, connection->version)) &&
+       (MHD_str_equal_caseless_(MHD_HTTP_VERSION_1_1, connection->version)) &&
        (NULL ==
         MHD_lookup_connection_value (connection,
                                      MHD_HEADER_KIND,
@@ -1945,7 +1947,7 @@ parse_connection_headers (struct MHD_Connection *connection)
   if (NULL != enc)
     {
       connection->remaining_upload_size = MHD_SIZE_UNKNOWN;
-      if (0 == strcasecmp (enc, "chunked"))
+      if (MHD_str_equal_caseless_(enc, "chunked"))
         connection->have_chunked_upload = MHD_YES;
     }
   else
@@ -2289,6 +2291,7 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
   unsigned int timeout;
   const char *end;
   char *line;
+  int client_close;
 
   connection->in_idle = MHD_YES;
   while (1)
@@ -2387,9 +2390,9 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
               break;
             }
           if ( (NULL != connection->response) &&
-	       ( (0 == strcasecmp (connection->method,
+	       ( (MHD_str_equal_caseless_ (connection->method,
 				   MHD_HTTP_METHOD_POST)) ||
-		 (0 == strcasecmp (connection->method,
+		 (MHD_str_equal_caseless_ (connection->method,
 				   MHD_HTTP_METHOD_PUT))) )
             {
               /* we refused (no upload allowed!) */
@@ -2587,6 +2590,7 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
           end =
             MHD_get_response_header (connection->response,
 				     MHD_HTTP_HEADER_CONNECTION);
+          client_close = ((NULL != end) && (0 == strcasecmp (end, "close")));
           MHD_destroy_response (connection->response);
           connection->response = NULL;
           if ( (NULL != daemon->notify_completed) &&
@@ -2602,7 +2606,8 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
             MHD_lookup_connection_value (connection, MHD_HEADER_KIND,
                                          MHD_HTTP_HEADER_CONNECTION);
           if ( (MHD_YES == connection->read_closed) ||
-               ((NULL != end) && (0 == strcasecmp (end, "close"))) )
+               (client_close) ||
+               ((NULL != end) && (MHD_str_equal_caseless_ (end, "close"))) )
             {
               connection->read_closed = MHD_YES;
               connection->read_buffer_offset = 0;
@@ -2913,7 +2918,7 @@ MHD_queue_response (struct MHD_Connection *connection,
   connection->response = response;
   connection->responseCode = status_code;
   if ( (NULL != connection->method) &&
-       (0 == strcasecmp (connection->method, MHD_HTTP_METHOD_HEAD)) )
+       (MHD_str_equal_caseless_ (connection->method, MHD_HTTP_METHOD_HEAD)) )
     {
       /* if this is a "HEAD" request, pretend that we
          have already sent the full message body */
@@ -2921,9 +2926,9 @@ MHD_queue_response (struct MHD_Connection *connection,
     }
   if ( (MHD_CONNECTION_HEADERS_PROCESSED == connection->state) &&
        (NULL != connection->method) &&
-       ( (0 == strcasecmp (connection->method,
+       ( (MHD_str_equal_caseless_ (connection->method,
 			   MHD_HTTP_METHOD_POST)) ||
-	 (0 == strcasecmp (connection->method,
+	 (MHD_str_equal_caseless_ (connection->method,
 			   MHD_HTTP_METHOD_PUT))) )
     {
       /* response was queued "early", refuse to read body / footers or
