@@ -75,20 +75,28 @@ extern MHD_PanicCallback mhd_panic;
  */
 extern void *mhd_panic_cls;
 
+/* If we have Clang or gcc >= 4.5, use __buildin_unreachable() */
+#if defined(__clang__) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 5)
+#define BUILTIN_NOT_REACHED __builtin_unreachable()
+#else
+#define BUILTIN_NOT_REACHED
+#endif
+
+
 #if HAVE_MESSAGES
 /**
  * Trigger 'panic' action based on fatal errors.
  *
  * @param msg error message (const char *)
  */
-#define MHD_PANIC(msg) mhd_panic (mhd_panic_cls, __FILE__, __LINE__, msg)
+#define MHD_PANIC(msg) do { mhd_panic (mhd_panic_cls, __FILE__, __LINE__, msg); BUILTIN_NOT_REACHED; } while (0)
 #else
 /**
  * Trigger 'panic' action based on fatal errors.
  *
  * @param msg error message (const char *)
  */
-#define MHD_PANIC(msg) mhd_panic (mhd_panic_cls, __FILE__, __LINE__, NULL)
+#define MHD_PANIC(msg) do { mhd_panic (mhd_panic_cls, __FILE__, __LINE__, NULL); BUILTIN_NOT_REACHED; } while (0)
 #endif
 
 
@@ -199,22 +207,6 @@ MHD_DLOG (const struct MHD_Daemon *daemon,
 	  const char *format, ...);
 #endif
 
-/**
- * Process escape sequences ('+'=space, %HH) Updates val in place; the
- * result should be UTF-8 encoded and cannot be larger than the input.
- * The result must also still be 0-terminated.
- *
- * @param cls closure (use NULL)
- * @param connection handle to connection, not used
- * @param val value to unescape (modified in the process)
- * @return length of the resulting val (strlen(val) maybe
- *  shorter afterwards due to elimination of escape sequences)
- */
-size_t
-MHD_http_unescape (void *cls,
-		   struct MHD_Connection *connection,
-		   char *val);
-
 
 /**
  * Header or cookie in HTTP request or response.
@@ -1099,6 +1091,15 @@ struct MHD_Daemon
    */
   MHD_socket socket_fd;
 
+  /**
+   * Whether to allow/disallow/ignore reuse of listening address.
+   * The semantics is the following:
+   * 0: ignore (user did not ask for neither allow/disallow, use SO_REUSEADDR)
+   * >0: allow (use SO_REUSEPORT on most platforms, SO_REUSEADDR on Windows)
+   * <0: disallow (mostly no action, SO_EXCLUSIVEADDRUSE on Windows)
+   */
+  int listening_address_reuse;
+
 #if EPOLL_SUPPORT
   /**
    * File descriptor associated with our epoll loop.
@@ -1131,10 +1132,15 @@ struct MHD_Daemon
    */
   int resuming;
 
+  /**
+   * Number of active parallel connections.
+   */
+  unsigned int connections;
+
   /**
    * Limit on the number of parallel connections.
    */
-  unsigned int max_connections;
+  unsigned int connection_limit;
 
   /**
    * After how many seconds of inactivity should
