@@ -36,6 +36,13 @@
 #include <unistd.h>
 #endif
 
+#if defined(CPU_COUNT) && (CPU_COUNT+0) < 2
+#undef CPU_COUNT
+#endif
+#if !defined(CPU_COUNT)
+#define CPU_COUNT 2
+#endif
+
 static int oneone;
 
 /**
@@ -267,7 +274,7 @@ testMultithreadedPoolPut ()
   d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_DEBUG,
                         1081,
                         NULL, NULL, &ahc_echo, &done_flag,
-                        MHD_OPTION_THREAD_POOL_SIZE, 4, 
+                        MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT,
 			MHD_OPTION_CONNECTION_MEMORY_LIMIT, (size_t) (1024*1024),
 			MHD_OPTION_END);
   if (d == NULL)
