@@ -23,7 +23,7 @@
  * @author Andrey Uzunov
  * @author Tatsuhiro Tsujikawa
  */
- 
+
 #include "platform.h"
 #include "microspdy.h"
 #include <sys/wait.h>
@@ -39,7 +39,7 @@ char *rcvbuf;
 int rcvbuf_c = 0;
 
 int session_closed_called = 0;
- 
+
 void
 killchild(int pid, char *message)
 {
@@ -55,7 +55,7 @@ killparent(int pid, char *message)
 	kill(pid, SIGKILL);
 	_exit(1);
 }
-		
+
 
 /*****
  * start of code needed to utilize spdylay
@@ -128,6 +128,8 @@ static char* strcopy(const char *s, size_t len)
 {
   char *dst;
   dst = malloc(len+1);
+  if (NULL == dst)
+    abort ();
   memcpy(dst, s, len);
   dst[len] = '\0';
   return dst;
@@ -201,20 +203,20 @@ static ssize_t send_callback(spdylay_session *session,
 {
   (void)session;
   (void)flags;
-  
+
   struct Connection *connection;
   ssize_t rv;
   connection = (struct Connection*)user_data;
   connection->want_io = IO_NONE;
 
-    rv = write(connection->fd, 
+    rv = write(connection->fd,
             data,
             length);
-            
+
     if (rv < 0)
     {
       switch(errno)
-      {				
+      {
         case EAGAIN:
   #if EAGAIN != EWOULDBLOCK
         case EWOULDBLOCK:
@@ -222,7 +224,7 @@ static ssize_t send_callback(spdylay_session *session,
           connection->want_io = WANT_WRITE;
           rv = SPDYLAY_ERR_WOULDBLOCK;
           break;
-          
+
         default:
           rv = SPDYLAY_ERR_CALLBACK_FAILURE;
       }
@@ -242,20 +244,20 @@ static ssize_t recv_callback(spdylay_session *session,
 {
   (void)session;
   (void)flags;
-  
+
   struct Connection *connection;
   ssize_t rv;
   connection = (struct Connection*)user_data;
   connection->want_io = IO_NONE;
 
-    rv = read(connection->fd, 
+    rv = read(connection->fd,
             buf,
             length);
-            
+
     if (rv < 0)
     {
       switch(errno)
-      {				
+      {
         case EAGAIN:
   #if EAGAIN != EWOULDBLOCK
         case EWOULDBLOCK:
@@ -263,7 +265,7 @@ static ssize_t recv_callback(spdylay_session *session,
           connection->want_io = WANT_READ;
           rv = SPDYLAY_ERR_WOULDBLOCK;
           break;
-          
+
         default:
           rv = SPDYLAY_ERR_CALLBACK_FAILURE;
       }
@@ -285,7 +287,7 @@ static void before_ctrl_send_callback(spdylay_session *session,
                                       void *user_data)
 {
   (void)user_data;
-  
+
   if(type == SPDYLAY_SYN_STREAM) {
     struct Request *req;
     int stream_id = frame->syn_stream.stream_id;
@@ -302,7 +304,7 @@ static void on_ctrl_send_callback(spdylay_session *session,
                                   spdylay_frame *frame, void *user_data)
 {
   (void)user_data;
-  
+
   char **nv;
   const char *name = NULL;
   int32_t stream_id;
@@ -329,7 +331,7 @@ static void on_ctrl_recv_callback(spdylay_session *session,
                                   spdylay_frame *frame, void *user_data)
 {
   (void)user_data;
-  
+
   struct Request *req;
   char **nv;
   const char *name = NULL;
@@ -375,7 +377,7 @@ static void on_stream_close_callback(spdylay_session *session,
 {
   (void)status_code;
   (void)user_data;
-  
+
   struct Request *req;
   req = spdylay_session_get_stream_user_data(session, stream_id);
   if(req) {
@@ -400,7 +402,7 @@ static void on_data_chunk_recv_callback(spdylay_session *session, uint8_t flags,
 {
   (void)flags;
   (void)user_data;
-  
+
   struct Request *req;
   req = spdylay_session_get_stream_user_data(session, stream_id);
   if(req) {
@@ -424,13 +426,13 @@ static void on_data_chunk_recv_callback(spdylay_session *session, uint8_t flags,
     } else {
       /* TODO add support gzip */
       fwrite(data, 1, len, stdout);
-      
+
       //check if the data is correct
       //if(strcmp(RESPONSE_BODY, data) != 0)
 		//killparent(parent, "\nreceived data is not the same");
       if(len + rcvbuf_c > strlen(RESPONSE_BODY))
 		killparent(parent, "\nreceived data is not the same");
-	
+
 		strcpy(rcvbuf + rcvbuf_c,(char*)data);
 		rcvbuf_c+=len;
     }
@@ -617,6 +619,8 @@ static void fetch_uri(const struct URI *uri)
 
   /* Establish connection and setup SSL */
   fd = connect_to(req.host, req.port);
+  if (-1 == fd)
+    abort ();
 
   connection.fd = fd;
   connection.want_io = IO_NONE;
@@ -746,7 +750,7 @@ static int parse_uri(struct URI *res, const char *uri)
 /*****
  * end of code needed to utilize spdylay
  */
- 
+
 
 /*****
  * start of code needed to utilize microspdy
@@ -774,21 +778,21 @@ standard_request_handler(void *cls,
 	(void)method;
 	(void)version;
 	(void)more;
-  
+
 	struct SPDY_Response *response=NULL;
-	
+
 	if(strcmp(CLS,cls)!=0)
 	{
 		killchild(child,"wrong cls");
 	}
-	
+
 	response = SPDY_build_response(200,NULL,SPDY_HTTP_VERSION_1_1,NULL,RESPONSE_BODY,strlen(RESPONSE_BODY));
-	
+
 	if(NULL==response){
 		fprintf(stdout,"no response obj\n");
 		exit(3);
 	}
-	
+
 	if(SPDY_queue_response(request,response,true,false,NULL,(void*)strdup(path))!=SPDY_YES)
 	{
 		fprintf(stdout,"queue\n");
@@ -802,12 +806,12 @@ session_closed_handler (void *cls,
 						int by_client)
 {
 	printf("session_closed_handler called\n");
-	
+
 	if(strcmp(CLS,cls)!=0)
 	{
 		killchild(child,"wrong cls");
 	}
-	
+
 	if(SPDY_YES != by_client)
 	{
 		//killchild(child,"wrong by_client");
@@ -817,12 +821,12 @@ session_closed_handler (void *cls,
 	{
 		printf("session closed by client\n");
 	}
-	
+
 	if(NULL == session)
 	{
 		killchild(child,"session is NULL");
 	}
-	
+
 	session_closed_called = 1;
 }
 
@@ -830,7 +834,7 @@ session_closed_handler (void *cls,
 /*****
  * end of code needed to utilize microspdy
  */
- 
+
 //child process
 void
 childproc(int port)
@@ -839,7 +843,7 @@ childproc(int port)
   struct sigaction act;
   int rv;
   char *uristr;
-  
+
   memset(&act, 0, sizeof(struct sigaction));
   act.sa_handler = SIG_IGN;
   sigaction(SIGPIPE, &act, 0);
@@ -854,7 +858,7 @@ childproc(int port)
     killparent(parent,"parse_uri failed");
   }
   fetch_uri(&uri);
-  
+
   if(strcmp(rcvbuf, RESPONSE_BODY))
     killparent(parent,"received data is different");
 }
@@ -872,9 +876,9 @@ parentproc( int port)
 	fd_set except_fd_set;
 	int maxfd = -1;
 	struct SPDY_Daemon *daemon;
-	
+
 	SPDY_init();
-	
+
 	daemon = SPDY_start_daemon(port,
 								NULL,
 								NULL,
@@ -882,7 +886,7 @@ parentproc( int port)
                 SPDY_DAEMON_OPTION_IO_SUBSYSTEM, SPDY_IO_SUBSYSTEM_RAW,
                 SPDY_DAEMON_OPTION_FLAGS, SPDY_DAEMON_FLAG_NO_DELAY,
                 SPDY_DAEMON_OPTION_END);
-	
+
 	if(NULL==daemon){
 		printf("no daemon\n");
 		return 1;
@@ -905,14 +909,14 @@ parentproc( int port)
 			timeout.tv_sec = timeoutlong / 1000;
 			timeout.tv_usec = (timeoutlong % 1000) * 1000;
 		}
-		
+
 		maxfd = SPDY_get_fdset (daemon,
 								&read_fd_set,
-								&write_fd_set, 
+								&write_fd_set,
 								&except_fd_set);
-								
+
 		ret = select(maxfd+1, &read_fd_set, &write_fd_set, &except_fd_set, &timeout);
-		
+
 		switch(ret) {
 			case -1:
 				printf("select error: %i\n", errno);
@@ -934,9 +938,9 @@ parentproc( int port)
 	SPDY_run(daemon);
 
 	SPDY_stop_daemon(daemon);
-	
+
 	SPDY_deinit();
-	
+
 	return WEXITSTATUS(childstatus);
 }
 
@@ -944,21 +948,21 @@ int main()
 {
 	int port = get_port(12123);
 	parent = getpid();
- 
+
    child = fork();
    if (child == -1)
-   {   
+   {
       fprintf(stderr, "can't fork, error %d\n", errno);
       exit(EXIT_FAILURE);
    }
- 
+
    if (child == 0)
    {
       childproc(port);
       _exit(0);
    }
    else
-   { 
+   {
 	   int ret = parentproc(port);
 	   if(1 == session_closed_called && 0 == ret)
       exit(0);
